/************************************************************************/
/*  Routine to create and write holdings record.			*/
/*									*/
/*	Douglas Neuhauser						*/
/*	Seismological Laboratory					*/
/*	University of California, Berkeley				*/
/*	doug@seismo.berkeley.edu					*/
/*									*/
/************************************************************************/

/*
 * Copyright (c) 1999 The Regents of the University of California.
 * All Rights Reserved.
 * 
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for educational, research and non-profit purposes,
 * without fee, and without a written agreement is hereby granted,
 * provided that the above copyright notice, this paragraph and the
 * following three paragraphs appear in all copies.
 * 
 * Permission to incorporate this software into commercial products may
 * be obtained from the Office of Technology Licensing, 2150 Shattuck
 * Avenue, Suite 510, Berkeley, CA  94704.
 * 
 * IN NO EVENT SHALL THE UNIVERSITY OF CALIFORNIA BE LIABLE TO ANY PARTY
 * FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES,
 * INCLUDING LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND
 * ITS DOCUMENTATION, EVEN IF THE UNIVERSITY OF CALIFORNIA HAS BEEN
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * THE UNIVERSITY OF CALIFORNIA SPECIFICALLY DISCLAIMS ANY WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE
 * PROVIDED HEREUNDER IS ON AN "AS IS" BASIS, AND THE UNIVERSITY OF
 * CALIFORNIA HAS NO OBLIGATIONS TO PROVIDE MAINTENANCE, SUPPORT,
 * UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
 */

#ifndef lint
static char sccsid[] = "$Id: write_holdings.c,v 1.3 2000/10/26 13:39:15 doug Exp $ ";
#endif

#include <stdio.h>
#include <math.h>
#include <string.h>
#include <time.h>
#define	MAXNAMLEN	255

#include "qlib2.h"

#include "holdings.h"
#include "rdseed.h"
#include "externals.h"
#include "procs.h"

#define	dummy_end	"2035,365,23:59:59.9999"
#define	dummy_filename  ""

/************************************************************************/
/*  write_holdings -							*/
/*	Create and write holdings record.				*/
/*  return:								*/
/*	0 for no error, non-zero on error.				*/
/************************************************************************/
int write_holding 
   (struct type50 *type50,	/* ptr to type50 station structure.	*/
    struct type52 *type52)	/* ptr to type52 channel structure.	*/
{
    HOLDING_REC	hr;		/* holdings record.			*/
    char	str[80];
    char	mode[10];
    INT_TIME	start_time, end_time, *it;
    int		size_kb = 0;
    time_t	unix_time = 0;
    char	*end_str;
    SDR_TIME	sdr_time;

    capntstr(hr.station, type50->station, HR_STATION_LEN);
    capntstr(hr.network, (type50->network_code) ? type50->network_code :
	   network, HR_NETWORK_LEN);
    capntstr(hr.channel, type52->channel, HR_CHANNEL_LEN);
    sprintf (str,"%10.4f",type52->samplerate);
    capntstr(hr.samples_per_sec, str, HR_SPS_LEN);
    capntstr(hr.mode, type52->channel_flag, HR_MODE_LEN);
    capntint(hr.num_segments, 0, HR_NUM_SEGMENTS_LEN);
    
    if ((it = parse_date(type52->start)) != NULL) {
	start_time = *it;
    }
    else {
	fprintf (stderr, "unable to parse date: %s\n", type52->start);
	return (-1);
    }
    end_str = (type52->end) ? type52->end : dummy_end;
    if ((it = parse_date (end_str)) != NULL) 
	end_time = *it;
    else {
	fprintf (stderr, "unable to parse date: %s\n", end_str);
	return (-1);
    }

    sdr_time = encode_time_sdr (start_time,my_wordorder);
    asc_sdr_time (str,sdr_time, my_wordorder);
    capntstr(hr.start_time, str, HR_START_TIME_LEN);
    unix_time = unix_time_from_sdr_time (sdr_time, my_wordorder);
    capntlong(hr.unix_start_time, unix_time, HR_UNIX_START_LEN);
    
    sdr_time = encode_time_sdr (end_time, my_wordorder);
    asc_sdr_time (str,sdr_time, my_wordorder);
    capntstr(hr.end_time, str, HR_END_TIME_LEN);
    unix_time = unix_time_from_sdr_time (sdr_time, my_wordorder);
    capntlong(hr.unix_end_time, unix_time, HR_UNIX_END_LEN);

    capntint(hr.file_kb,size_kb,HR_FILE_KB_LEN);

    capntstr(hr.dcc, dcc, HR_DCC_LEN);
    capntstr(hr.incoming_medium, "D", HR_MEDIUM_LEN);
    capntstr(hr.data_filename, dummy_filename, HR_DATA_FILE_LEN);
    capntstr(hr.header_dir, header_dir, HR_HEADER_DIR_LEN);
    capntstr(hr.operator, operator, HR_OPERATOR_LEN);

    /*	Convert final tab to a null since a holdings record consists	*/
    /*	of tab-separted fields and is terminated by a newline.		*/
    hr.operator[HR_OPERATOR_LEN] = '\0';
    puts((char *)&hr);
    fflush (stdout);
    return (0);
}
